@@ -9,9 +9,9 @@ use strict;
 use warnings;
 
 use base qw( Tickit::Widget );
-Tickit::Window->VERSION( '0.42' );
+Tickit::Window->VERSION( '0.57' );  # ->bind_event
 
-our $VERSION = '0.019';
+our $VERSION = '0.020';
 
 use Scalar::Util qw( weaken );
 use Tickit::Utils qw( textwidth );
@@ -466,13 +466,13 @@ sub scroll_to_visible {
                 );
                 $prev_more->[2] = $w;
                 $w->set_pen( $self->{tabbed}->get_style_pen( "more" ) );
-                $w->set_on_expose( with_rb => sub {
-                        my ( undef, $rb, $rect ) = @_;
-                        $rb->text_at( 0, 0, $prev_more->[0] );
+                $w->bind_event( expose => sub {
+                        my ( $win, undef, $info ) = @_;
+                        $info->rb->text_at( 0, 0, $prev_more->[0] );
                 });
-                $w->set_on_mouse( with_ev => sub {
-                        my ( undef, $ev ) = @_;
-                        $self->_scroll_left if $ev->type eq "press" && $ev->button == 1;
+                $w->bind_event( mouse => sub {
+                        my ( $win, undef, $info ) = @_;
+                        $self->_scroll_left if $info->type eq "press" && $info->button == 1;
                         return 1;
                 } );
         }
@@ -487,13 +487,13 @@ sub scroll_to_visible {
                 );
                 $next_more->[2] = $w;
                 $w->set_pen( $self->{tabbed}->get_style_pen( "more" ) );
-                $w->set_on_expose( with_rb => sub {
-                        my ( undef, $rb, $rect ) = @_;
-                        $rb->text_at( 0, 0, $next_more->[0] );
+                $w->bind_event( expose => sub {
+                        my ( $win, undef, $info ) = @_;
+                        $info->rb->text_at( 0, 0, $next_more->[0] );
                 } );
-                $w->set_on_mouse( with_ev => sub {
-                        my ( undef, $ev ) = @_;
-                        $self->_scroll_right if $ev->type eq "press" && $ev->button == 1;
+                $w->bind_event( mouse => sub {
+                        my ( $win, undef, $info ) = @_;
+                        $self->_scroll_right if $info->type eq "press" && $info->button == 1;
                         return 1;
                 } );
         }
